@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1998, 2002-2007 Kiyoshi Matsui <kmatsui@t3.rim.or.jp>
+ * Copyright (c) 1998, 2002-2008 Kiyoshi Matsui <kmatsui@t3.rim.or.jp>
  * All rights reserved.
  *
  * Some parts of this code are derived from the public domain software
@@ -173,7 +173,7 @@ typedef struct sizes {
 } SIZES;
 
 /*
- * S_CHAR etc.  define the sizeof the basic TARGET machine word types.
+ * S_CHAR, etc.  define the sizeof the basic TARGET machine word types.
  *      By default, sizes are set to the values for the HOST computer.  If
  *      this is inappropriate, see those tables for details on what to change.
  *      Also, if you have a machine where sizeof (signed int) differs from
@@ -196,7 +196,8 @@ typedef struct sizes {
 #define S_PDOUBLE   (sizeof (double *))
 #define S_PFPTR     (sizeof (int (*)()))
 #if HAVE_LONG_LONG
-#if HOST_COMPILER == BORLANDC
+#if (HOST_COMPILER == BORLANDC)
+        || (HOST_COMPILER == MSC && defined(_MSC_VER) && (_MSC_VER < 1300))
 #define S_LLINT     (sizeof (__int64))
 #define S_PLLINT    (sizeof (__int64 *))
 #else
@@ -273,7 +274,7 @@ void    init_eval( void)
 expr_t  eval_if( void)
 /*
  * Evaluate a #if expression.  Straight-forward operator precedence.
- * This is called from directive() on encountering an #if statement.
+ * This is called from directive() on encountering an #if directive.
  * It calls the following routines:
  * eval_lex()   Lexical analyser -- returns the type and value of
  *              the next input token.
@@ -364,10 +365,10 @@ expr_t  eval_if( void)
                 if (op == OP_LPA) {
                     prec = OP_RPA_PREC;
                     if (standard && (warn_level & 4)
-                            && ++parens == exp_nest_min + 1)
+                            && ++parens == std_limits.exp_nest + 1)
                         cwarn(
                     "More than %.0s%ld nesting of parens"   /* _W4_ */
-                            , NULL, (long) exp_nest_min, NULL);
+                            , NULL, (long) std_limits.exp_nest, NULL);
                 } else if (op == OP_QUE) {
                     prec = OP_QUE_PREC;
                 } else if (is_unary( op)) {
@@ -484,8 +485,8 @@ expr_t  eval_if( void)
 
 static int  eval_lex( void)
 /*
- * Return next operator or value to evaluate.  Called from eval_if().  It calls
- * a special-purpose routines for character constants and numeric values:
+ * Return next operator or constant to evaluate.  Called from eval_if().  It 
+ * calls a special-purpose routines for character constants and numeric values:
  *      eval_char()     called to evaluate 'x'
  *      eval_num()      called to evaluate numbers
  * C++98 treats 11 identifier-like tokens as operators.
@@ -500,6 +501,8 @@ static int  eval_lex( void)
 
     ev.sign = SIGNED;                       /* Default signedness   */
     ev.val = 0L;            /* Default value (on error or 0 value)  */
+    in_if = ! skip; /* Inform to expand_macro() that the macro is   */
+                    /*      in #if line and not skipped expression. */
     c = skip_ws();
     if (c == '\n') {
         unget_ch();
@@ -518,8 +521,13 @@ static int  eval_lex( void)
             if (c == '(')                   /* Allow defined (name) */
                 c = skip_ws();
             if (scan_token( c, (workp = work_buf, &workp), work_end) == NAM) {
-                if (warn)
-                    ev.val = (look_id( identifier) != NULL);
+                DEFBUF *    defp = look_id( identifier);
+                if (warn) {
+                    ev.val = (defp != NULL);
+                    if ((mcpp_debug & MACRO_CALL) && ! skip && defp)
+                        /* Annotate if the macro is in non-skipped expr.    */
+                        mcpp_fprintf( OUT, "/*%s*/", defp->name);
+                }
                 if (c1 != '(' || skip_ws() == ')')  /* Balanced ?   */
                     return  VAL;            /* Parsed ok            */
             }
@@ -732,7 +740,7 @@ no_good:
 }
 
 static int  look_type(
-    int typecode
+    int     typecode
 )
 {
     const char * const  unknown_type
@@ -835,7 +843,7 @@ VAL_SIGN *  eval_num(
 
     ev.sign = SIGNED;                       /* Default signedness   */
     ev.val = 0L;                            /* Default value        */
-    if ((char_type[ c = *cp++ & UCHARMAX] & DIG) == 0)   /* Dot          */
+    if ((char_type[ c = *cp++ & UCHARMAX] & DIG) == 0)   /* Dot     */
         goto  num_err;
     if (c != '0') {                         /* Decimal              */
         base = 10;
@@ -956,7 +964,7 @@ num_err:
 }
 
 static VAL_SIGN *   eval_char(
-    char * const token
+    char * const    token
 )
 /*
  * Evaluate a character constant.
@@ -996,7 +1004,7 @@ static VAL_SIGN *   eval_char(
         cp++;                           /* Skip 'L'                 */
         bits = mbits;
     }
-    if (char_type[ *cp & UCHARMAX] & mbstart) {
+    if (char_type[ *cp & UCHARMAX] & mbchk) {
         cl = mb_eval( &cp);
         bits = mbits;
     } else if ((cl = eval_one( &cp, wide, mbits, (ucn8 = FALSE, &ucn8)))
@@ -1008,7 +1016,7 @@ static VAL_SIGN *   eval_char(
     value = cl;
 
     for (i = 0; *cp != '\'' && *cp != EOS; i++) {
-        if (char_type[ *cp & UCHARMAX] & mbstart) {
+        if (char_type[ *cp & UCHARMAX] & mbchk) {
             cl = mb_eval( &cp);
             if (cl == 0)
                 /* Shift-out sequence of multi-byte or wide character   */
@@ -1261,8 +1269,8 @@ range_err:
 }
 
 static VAL_SIGN *   eval_eval(
-    VAL_SIGN * valp,
-    int op
+    VAL_SIGN *  valp,
+    int         op
 )
 /*
  * One or two values are popped from the value stack and do arithmetic.
@@ -1367,9 +1375,9 @@ static VAL_SIGN *   eval_eval(
 
 static expr_t   eval_signed(
     VAL_SIGN ** valpp,
-    expr_t v1,
-    expr_t v2,
-    int op
+    expr_t      v1,
+    expr_t      v2,
+    int         op
 )
 /*
  * Apply the argument operator to the signed data.
@@ -1494,7 +1502,7 @@ static expr_t   eval_signed(
 }
 
 static expr_t   eval_unsigned(
-    VAL_SIGN **     valpp,
+    VAL_SIGN ** valpp,
     uexpr_t     v1u,
     uexpr_t     v2u,
     int         op
@@ -1618,8 +1626,8 @@ static void overflow(
 }
 
 static void dump_val(
-    const char * msg,
-    const VAL_SIGN * valp
+    const char *        msg,
+    const VAL_SIGN *    valp
 )
 /*
  * Dump a value by internal representation.
